@@ -15,12 +15,14 @@ require Exporter;
 
 our @ISA = qw /Exporter/;
 
-our @EXPORT = qw / _hardware /;
+our @EXPORT = qw / _hardware /; 
 
+use Apache::Ocsinventory::Server::Inventory::Cache;
 use Apache::Ocsinventory::Server::Constants;
 use Apache::Ocsinventory::Server::System qw / :server /;
 
 sub _hardware{
+  my $sectionMeta = shift;
   my $result = $Apache::Ocsinventory::CURRENT_CONTEXT{'XML_ENTRY'};
   my $base = $result->{CONTENT}->{HARDWARE};
   my $ua = $Apache::Ocsinventory::CURRENT_CONTEXT{'USER_AGENT'};
@@ -43,22 +45,37 @@ sub _hardware{
 	OSVERSION=".$dbh->quote($base->{OSVERSION}).",
 	OSCOMMENTS=".$dbh->quote($base->{OSCOMMENTS}).",
 	PROCESSORT=".$dbh->quote($base->{PROCESSORT}).", 
-	PROCESSORS=".(defined($base->{PROCESSORS})?$dbh->quote($base->{PROCESSORS}):0).", 
-	PROCESSORN=".(defined($base->{PROCESSORN})?$dbh->quote($base->{PROCESSORN}):0).", 
-	MEMORY=".(defined($base->{MEMORY})?$dbh->quote($base->{MEMORY}):0).",
-	SWAP=".(defined($base->{SWAP})?$dbh->quote($base->{SWAP}):0).",
+	PROCESSORS=".(defined($base->{PROCESSORS})?$base->{PROCESSORS}:0).", 
+	PROCESSORN=".(defined($base->{PROCESSORN})?$base->{PROCESSORN}:0).", 
+	MEMORY=".(defined($base->{MEMORY})?$base->{MEMORY}:0).",
+	SWAP=".(defined($base->{SWAP})?$base->{SWAP}:0).",
 	IPADDR=".$dbh->quote($ipAddress).",
+	DNS=".$dbh->quote($base->{DNS}).",
+	DEFAULTGATEWAY=".$dbh->quote($base->{DEFAULTGATEWAY}).",
 	ETIME=NULL,
 	$userid
-	TYPE=".(defined($base->{TYPE})?$dbh->quote($base->{TYPE}):0).",
+	TYPE=".(defined($base->{TYPE})?$base->{TYPE}:0).",
 	DESCRIPTION=".$dbh->quote($base->{DESCRIPTION}).",
 	WINCOMPANY=".$dbh->quote($base->{WINCOMPANY}).",
 	WINOWNER=".$dbh->quote($base->{WINOWNER}).",
 	WINPRODID=".$dbh->quote($base->{WINPRODID}).",
-	WINPRODKEY=".$dbh->quote($base->{WINPRODKEY})."
+	WINPRODKEY=".$dbh->quote($base->{WINPRODKEY}).",
+	IPSRC=".$dbh->quote($Apache::Ocsinventory::CURRENT_CONTEXT{IPADDRESS}).",
+	UUID=".$dbh->quote($base->{UUID})."
 	 WHERE ID=".$deviceId)
   or return(1);
-	
+
+  #We feed cache tables associated to hardware fields
+  if ($ENV{OCS_OPT_INVENTORY_CACHE_ENABLED}) {
+    my $cache_values =[];
+
+    for (keys %{ $sectionMeta->{field_cached}} ) {
+      #Feeding array for cache values
+      $cache_values->[ $sectionMeta->{field_cached}->{$_} ] = $base->{$_};
+    }
+    &_cache( 'add', 'hardware', $sectionMeta, $cache_values );
+  }
+
   $dbh->commit unless $ENV{'OCS_OPT_INVENTORY_TRANSACTION'};
   0;
 }
